@@ -31,18 +31,20 @@ from coopr.solvers.mockmip import MockMIP
 
 logger = logging.getLogger('coopr.solvers')
 
-global cbc_compiled_with_asl
-global _cbc_old_version
-cbc_compiled_with_asl = None
+def _version_to_string(version):
+    if version is None:
+        return "<unknown>"
+    return ('.'.join(str(i) for i in version))
+
+_cbc_compiled_with_asl = None
 _cbc_version = None
-_cbc_old_version = False
+_cbc_old_version = None
 def configure_cbc():
-    global cbc_compiled_with_asl
+    global _cbc_compiled_with_asl
     global _cbc_version
     global _cbc_old_version
-    if cbc_compiled_with_asl is not None:
+    if _cbc_compiled_with_asl is not None:
         return
-    cbc_compiled_with_asl = False
     # manually look for the cbc executable to prevent the
     # CBC.execute() from logging an error when CBC is missing
     if pyutilib.services.registered_executable("cbc") is None:
@@ -52,10 +54,9 @@ def configure_cbc():
     _cbc_version = _extract_version(results[1])
     results = pyutilib.subprocess.run( 
         [cbc_exec,"dummy","-AMPL","-stop"], timelimit=1 )
-    cbc_compiled_with_asl = not ('No match for AMPL' in results[1])
-    if _cbc_version < (2,7,0,0):
-        _cbc_old_version = True
-        return
+    _cbc_compiled_with_asl = not ('No match for AMPL' in results[1])
+    if _cbc_version is not None:
+        _cbc_old_version = _cbc_version < (2,7,0,0)
 
 
 class CBC(OptSolver):
@@ -79,20 +80,28 @@ class CBC(OptSolver):
             return opt
         #
         if mode == 'nl':
-            if cbc_compiled_with_asl:
-                if _cbc_old_version:
-                    logger.error("found CBC version ("+('.'.join(str(i) for i in _cbc_version))+") < 2.7; ASL support disabled.")
-                    logger.error("Upgrade CBC to activate ASL support in this plugin")
-                    return
-                # CBC doesn't not accept all asl style command line options
-                # (-s in particular, which is required for streaming output of 
-                # all asl solvers). Therefore we need to send it through the cbc_shell
-                # instead of ASL
-                opt = SolverFactory('_cbc_shell',**kwds)
-                opt.set_problem_format(ProblemFormat.nl)
+            # the _cbc_compiled_with_asl and
+            # _cbc_old_version flags are tristate
+            # (None, False, True), so don't
+            # simplify the if statements from 
+            # checking "is"
+            if _cbc_compiled_with_asl is not False:
+                if _cbc_old_version is True:
+                    logger.warn("found CBC version "
+                                 +_version_to_string(_cbc_version)+
+                                 " < 2.7; ASL support disabled.")
+                    logger.warn("Upgrade CBC to activate ASL "
+                                 "support in this plugin")
             else:
-                logger.error('CBC solver is not compiled with ASL interface.')
-                return
+                logger.warn("CBC solver is not compiled with ASL "
+                             "interface.")
+            # CBC doesn't not accept all asl style command line
+            # options (-s in particular, which is required for
+            # streaming output of all asl solvers). Therefore we need
+            # to send it through the cbc_shell instead of ASL
+            opt = SolverFactory('_cbc_shell',**kwds)
+            opt.set_problem_format(ProblemFormat.nl)
+            return opt
         elif mode == 'os':
             opt = SolverFactory('_ossolver', **kwds)
         else:
@@ -119,11 +128,13 @@ class CBCSHELL(SystemCallSolver):
         # Set up valid problem formats and valid results for each problem format
         #
         self._valid_problem_formats=[ProblemFormat.cpxlp, ProblemFormat.mps]
-        if cbc_compiled_with_asl:
+        if (_cbc_compiled_with_asl is not False) and \
+           (_cbc_old_version is not True):
             self._valid_problem_formats.append(ProblemFormat.nl)
         self._valid_result_formats={}
         self._valid_result_formats[ProblemFormat.cpxlp] = [ResultsFormat.soln]
-        if cbc_compiled_with_asl:
+        if (_cbc_compiled_with_asl is not False) and \
+           (_cbc_old_version is not True):
             self._valid_result_formats[ProblemFormat.nl] = [ResultsFormat.sol]
         self._valid_result_formats[ProblemFormat.mps] = [ResultsFormat.soln]
 
