@@ -285,7 +285,7 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
         #
         # Define command line
         #
-        cmd = [self.executable()]
+        cmd = [executable]
         if self._timer:
             cmd.insert(0, self._timer)
         return pyutilib.misc.Bunch( cmd=cmd, script=script, 
