@@ -287,7 +287,7 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
         #
         # Define command line
         #
-        cmd = [self.executable()]
+        cmd = [executable]
         if self._timer:
             cmd.insert(0, self._timer)
         return pyutilib.misc.Bunch( cmd=cmd, script=script, 
